@@ -340,7 +340,7 @@ class OvsHost(linux.LinuxDevice):
         '''
         Add some flows to ofproto
         '''
-        #print("mac: %s" %(self.macs))
+        #self.log("mac: %s" %(self.macs))
         if (gw["mac"] not in self.macs):
             # gw is not on this node, Add it as if it's on this node.
             ipaddr = ipaddress.ip_interface(gw["ip"]).ip
@@ -353,9 +353,9 @@ class OvsHost(linux.LinuxDevice):
 
         for d in args:
             #self.log("d: %s" %(d))
-            if d.get("type", None) not in ["vm", "container"]:
-                self.log("Don't support device type: %s" %(d.get("type", None)))
-                continue
+            #if d.get("type", None) not in ["vm", "container"]:
+            #    self.log("Don't support device type: %s" %(d.get("type", None)))
+            #    continue
             if (d["mac"] in self.macs):
                 # ONly change the mac and ttl on the same host.
                 self.ofctl_add_flow(bridge_name,
@@ -474,12 +474,11 @@ class OvsHost(linux.LinuxDevice):
                     self.cmd('ovs-ofctl add-flow %s %s' %(bridge_name, l))
         return None
 
-    def ping_test (self, src, dsts):
+    def ping_test (self, src, *args, **kwargs):
         '''
         Add some flows to ofproto
         '''
-        dsts = dsts if (isinstance(dsts, list)) else [dsts]
-        for dst in dsts:
+        for dst in args:
             dstip = ipaddress.ip_interface(dst["ip"])
             if src["type"] == "container":
                 srcip = ipaddress.ip_interface(src["ip"])
@@ -487,13 +486,15 @@ class OvsHost(linux.LinuxDevice):
                         %(src["name"], dstip.ip))
             elif src["type"] == "vm":
                 srcip = ipaddress.ip_interface(src["port"][1]["ip"])
-                if dstip.ip not in srcip.network:
-                    # warning to configure the route.
-                    self.log("WARNING: don't forget to configure route to %s!"
-                            %(dstip.ip), bg_color = "purple")
-                result = self.cmd('sshpass -p %s ssh %s@%s ping -c 1 %s'
-                    %(src["password"], src["username"],
-                        src["port"][0]["ip"].split("/")[0], dstip.ip))
+                u = urlparse.urlparse(src["url"])
+
+                if (u.password):
+                    result = self.cmd('sshpass -p %s ssh %s@%s ping -c 1 %s'
+                        %(u.password, u.username, u.hostname, dstip.ip))
+                else:
+                    # Maybe it doesn't need password
+                    result = self.cmd('ssh %s@%s ping -c 1 %s'
+                        %(u.username, u.hostname, dstip.ip))
             else:
                 self.log("ERROR: don't support the type %s!"
                         %(src["type"]), bg_color = "purple")
